# MDN CSS data

This folder contains data about the different features of the [CSS](https://developer.mozilla.org/en-US/docs/Web/CSS) language.

## Different types of CSS data

The CSS data is split into these parts:

* **at-rules**:
[data](https://github.com/mdn/data/blob/master/css/at-rules.json) |
[schema](https://github.com/mdn/data/blob/master/css/at-rules.schema.json) |
[docs](https://github.com/mdn/data/blob/master/css/at-rules.md)
* **properties**:
[data](https://github.com/mdn/data/blob/master/css/properties.json) |
[schema](https://github.com/mdn/data/blob/master/css/properties.schema.json) |
[docs](https://github.com/mdn/data/blob/master/css/properties.md)
* **selectors**:
[data](https://github.com/mdn/data/blob/master/css/selectors.json) |
[schema](https://github.com/mdn/data/blob/master/css/selectors.schema.json) |
[docs](https://github.com/mdn/data/blob/master/css/selectors.md)
* **syntaxes**:
[data](https://github.com/mdn/data/blob/master/css/syntaxes.json) |
[schema](https://github.com/mdn/data/blob/master/css/syntaxes.schema.json) |
[docs](https://github.com/mdn/data/blob/master/css/syntaxes.md)
* **types**:
[data](https://github.com/mdn/data/blob/master/css/types.json) |
[schema](https://github.com/mdn/data/blob/master/css/types.schema.json) |
[docs](https://github.com/mdn/data/blob/master/css/types.md)
* **units**:
[data](https://github.com/mdn/data/blob/master/css/units.json) |
[schema](https://github.com/mdn/data/blob/master/css/units.schema.json) |
[docs](https://github.com/mdn/data/blob/master/css/units.md)
